@@ -1,3 +1,3 @@
-is_bool <- function(x) {
+is_flag <- function(x) {
   is.logical(x) && length(x) == 1L && !is.na(x)
 }
